install_default_crypto_provider

Function install_default_crypto_provider 

pub fn install_default_crypto_provider()
Install Spin’s process-wide rustls crypto provider.

This is idempotent for Spin’s own duplicate calls from main and the trigger, but fails loudly if something else installed a rustls provider first.